summaryrefslogtreecommitdiff
path: root/src/core/parser/Parser.hpp
diff options
context:
space:
mode:
authorAndreas Stöckel <astoecke@techfak.uni-bielefeld.de>2015-01-01 18:06:04 +0100
committerAndreas Stöckel <andreas@somweyr.de>2015-01-01 18:06:04 +0100
commit4484f6deea0e098a140e878484d020bec839d1bd (patch)
treef3e8b480a533b4158abe9918f16d9988c6b463b6 /src/core/parser/Parser.hpp
parent377b7b0213733307927bec9e39c8ccb063e6ba50 (diff)
Using CharReader instead of inputstream in Parser function
Diffstat (limited to 'src/core/parser/Parser.hpp')
-rw-r--r--src/core/parser/Parser.hpp6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/core/parser/Parser.hpp b/src/core/parser/Parser.hpp
index 40ac87a..63303e2 100644
--- a/src/core/parser/Parser.hpp
+++ b/src/core/parser/Parser.hpp
@@ -34,6 +34,7 @@
#include <core/Node.hpp>
#include <core/Registry.hpp>
+#include <core/common/CharReader.hpp>
#include <core/common/Exceptions.hpp>
#include <core/common/Logger.hpp>
@@ -62,6 +63,7 @@ struct ParserContext {
* Reference to the Logger the parser should log any messages to.
*/
Logger &logger;
+
/**
* Reference to the Manager the parser should append nodes to.
*/
@@ -132,7 +134,7 @@ public:
* inclusion in the document graph. This method should be overridden by
* derived classes.
*
* @param is is a reference to the input stream that should be parsed.
* @param ctx is a reference to the context that should be used while
* parsing the document.
* @return a reference to the node representing the subgraph that has been
@@ -140,7 +142,7 @@ public:
* calling code will try to resolve these. If no valid node can be produced,
* a corresponding LoggableException must be thrown by the parser.
*/
- virtual Rooted<Node> parse(std::istream &is, ParserContext &ctx) = 0;
+ virtual Rooted<Node> parse(CharReader &reader, ParserContext &ctx) = 0;
/**
* Parses the given string and returns a corresponding node for
@@ -132,7 +134,7 @@ public:
* derived classes.
*
- * @param is is a reference to the input stream that should be parsed.
+ * @param reader is a reference to the CharReader that should be used.
* @param ctx is a reference to the context that should be used while
* parsing the document.